Installation
============

This assumes that you have Python installed. A thorough guide on installing
Python can be found `here <python_install>`_. We highly recommend using Sceptre from within a
``virtualenv``. Notes on installing and setting up ``virtualenv`` can be found
`here <http://docs.python-guide.org/en/latest/dev/virtualenvs/>`__.

Install Sceptre:

``pip install sceptre``

Validate installation by printing out Sceptre’s version number:

.. TODO resolve version in code

``sceptre --version``

.. TODO ask for fix from: https://github.com/sphinx-doc/sphinx/issues/3306

.. parsed-literal::

    Sceptre, version |version|

Update Sceptre:

``pip install sceptre -U``

.. _python_install: http://docs.python-guide.org/en/latest/starting/installation/
